@@ -14,11 +14,11 @@ structures.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 PRE-REQUISITES
 
@@ -34,11 +34,26 @@ Software / data:
 
 4. Modeller (version 9.14 https://salilab.org/modeller/)
 
-5. Local PDB directory (central or user-designated) - updated (http://www.rcsb.org). 
+5. DSSP (http://swift.cmbi.ru.nl/gv/dssp/)
+
+6. Local PDB directory (central or user-designated from http://www.rcsb.org). Many PDB structures
+   are incomplete with missing residues. The SmotifTF algorithm performs best when the PDB 
+   structures are complete. Hence, we use Modeller (https://salilab.org/modeller/) to model the 
+   missing residues in the PDB to obtain complete structures. The algorithm can work with 
+   incomplete PDB structures but the performance may not be as expected. The SMotifTF software 
+   can handle gzipped (.gz) or unzipped (.ent) PDB structure files. 
+
+   The software for remodeling the missing residues can be obtained from our website at: 
+   http://fiserlab.org/remodel_pdb.tar.gz
+   This can be used to remodel missing residues in the entire PDB and these remodeled
+   structures can be used in the SmotifTF package. The SmotifTF package can handle both
+   regular and remodeled PDB database.
 
 Download and install the above mentioned software / data according to their instructions. 
-Note: Psipred and Psiblast require legacy blast and Delta-blast is a part of the Blast+ package. 
 
+Note: Psipred may require legacy blast and Psiblast and Delta-blast are part of the Blast+ package. 
+      .ncbirc file may be required in the home directory for Psipred. 
+    
 =head1 DATABASES REQUIRED: 
 
 1. PDBAA blast database is required (ftp://ftp.ncbi.nlm.nih.gov/blast/db/). 
