@@ -31,9 +31,9 @@ my $PSIBLAST_EXEC = $psiblast->{'exec'};
 my $DB_PATH       = $psiblast->{'db_path'};
 
 my $deltablast    = $cfg->param( -block => 'deltablast' );
-my $DELTABLAST_PATH = $psiblast->{'path'};
-my $DELTABLAST_EXEC = $psiblast->{'exec'};
-my $DELTA_DB_PATH   = $psiblast->{'db_path'};
+my $DELTABLAST_PATH = $deltablast->{'path'};
+my $DELTABLAST_EXEC = $deltablast->{'exec'};
+my $DELTA_DB_PATH   = $deltablast->{'db_path'};
 
 
 =head1 SYNOPSIS
